植生調査用樹木位置図作成
treemap(plot.name = "Mimatsu")
# x11()
treemap("Bijodaira")
#> Warning: Removed 141 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: ggrepel: 24 unlabeled data points (too many overlaps). Consider increasing max.overlaps
treemap("Bunazaka")
#> Warning: Removed 187 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: ggrepel: 159 unlabeled data points (too many overlaps). Consider increasing max.overlaps
treemap("Bunadaira")
#> Warning: Removed 210 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: ggrepel: 46 unlabeled data points (too many overlaps). Consider increasing max.overlaps
treemap("Kaminokodaira")
#> Warning: Removed 175 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: ggrepel: 291 unlabeled data points (too many overlaps). Consider increasing max.overlaps
treemap("Matsuotoge")
#> Warning: Removed 326 rows containing non-finite outside the scale range
#> (`stat_contour()`).
treemap("Kagamiishi")
#> Warning: Removed 234 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#'
treemap("Mimatsu")
#> Warning: Removed 209 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: ggrepel: 21 unlabeled data points (too many overlaps). Consider increasing max.overlaps
treemap("Mimatsu")+ ggplot2::ylim(c(45, 105))
#> Warning: Contour data has duplicated x, y coordinates.
#> ℹ 680 duplicated rows have been dropped.
#> Warning: Removed 138 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: Removed 5 rows containing missing values or values outside the scale range
#> (`geom_hline()`).
#> Warning: Removed 149 rows containing missing values or values outside the scale range
#> (`geom_point()`).
#> Warning: Removed 149 rows containing missing values or values outside the scale range
#> (`geom_text_repel()`).
#> Warning: Removed 149 rows containing missing values or values outside the scale range
#> (`geom_text()`).
#> Warning: Removed 149 rows containing missing values or values outside the scale range
#> (`geom_text()`).
#> Warning: Removed 7 rows containing missing values or values outside the scale range
#> (`geom_path()`).
#> Warning: ggrepel: 2 unlabeled data points (too many overlaps). Consider increasing max.overlaps
treemap("Arimine")
#> Warning: Removed 175 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: ggrepel: 27 unlabeled data points (too many overlaps). Consider increasing max.overlaps
treemap("Arimine")+ ggplot2::xlim(c(-5, 55))+ ggplot2::ylim(c(-5, 60))
#> Warning: Contour data has duplicated x, y coordinates.
#> ℹ 1050 duplicated rows have been dropped.
#> Warning: Removed 90 rows containing non-finite outside the scale range
#> (`stat_contour()`).
#> Warning: Removed 5 rows containing missing values or values outside the scale range
#> (`geom_vline()`).
#> Warning: Removed 4 rows containing missing values or values outside the scale range
#> (`geom_hline()`).
#> Warning: Removed 205 rows containing missing values or values outside the scale range
#> (`geom_point()`).
#> Warning: Removed 221 rows containing missing values or values outside the scale range
#> (`geom_text_repel()`).
#> Warning: Removed 205 rows containing missing values or values outside the scale range
#> (`geom_text()`).
#> Warning: Removed 205 rows containing missing values or values outside the scale range
#> (`geom_text()`).
#'